@@ -9,21 +9,17 @@
 `neopixel` - NeoPixel strip driver
 ====================================================
 
-* Author(s): Damien P. George, Scott Shawcroft, Carter Nelson, Roy Hooper
+* Author(s): Damien P. George, Scott Shawcroft, Carter Nelson, Rose Hooper
 """
 
 # pylint: disable=ungrouped-imports
-import sys
 import digitalio
 from neopixel_write import neopixel_write
 
-if sys.implementation.version[0] < 5:
+try:
+    import _pixelbuf
+except ImportError:
     import adafruit_pypixelbuf as _pixelbuf
-else:
-    try:
-        import _pixelbuf
-    except ImportError:
-        import adafruit_pypixelbuf as _pixelbuf
 
 
 __version__ = "0.0.0-auto.0"
